      Program ESMDSMC

* Reformat into a smc file an ascii file obtained from the European 
* Strong-Motion Database

* The smc file name is constructed by appending ".smc" to the input file name.

* Sample control file:
* first line below starts the control, with line 1, col 1 = "N" in "Nominal":
*!Control file for ESMD2SMC      ! first line
*!Name of summary file:
* esmd2smc.sum
*!Spc?
* Y
*!Xfactr
* 100.0
*!Input file name ("stop" in any column to quit):
* \smsim\ts0.raw
* \smsim\ts1.raw
*STOP

* #### NOTE ####  This version only reads raw acceleration and corrected
*                 acceleration (not velocity and displacement).   It assumes
*                 evenly spaced data.

* Dates: 06/03/04 - Written by D. Boore, patterned after pea2smc
*        01/22/07 - Added "close(nu_asc)"; otherwise it runs out of unit
*                   numbers for a long list of files.
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats
*        04/23/09 - Minor change
!        03/29/10 - Minor changes

      character precision*8
      
      real(4), dimension(:), allocatable :: ts 
      character f_ctl*40, f_sum*40, f_asc*40, f_smc*40, f_asc_4*4
      character buf*80
      character char_head(11)*80, comments(100)*80, 
     : hdr_cmmnts(100)*200, cmnts2skip(20)*80

      character headers_query*10
      integer int_head(48)
      real real_head(50)

      logical f_ctl_exist, raw_query

      do i = 2, 11
        char_head(i) = '*'
      end do

      int_null = -32768
      do i = 1, 48
        int_head(i) = int_null
      end do
*      int_head(13) = 0
*      int_head(14) = 0

      real_null = 1.7e+38
      do i = 1, 50
        real_head(i) = real_null
      end do

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file ("Enter" = esmd2smc.ctl): '
        read(*, '(a)') f_ctl
        if (f_ctl(1:4) .eq. '    ') f_ctl = 'esmd2smc.ctl'
        call trim_c(f_ctl, nc_f_ctl)
        inquire(file=f_ctl(1:nc_f_ctl), exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do
      
      call get_lun(nu_ctl)
      open(unit=nu_ctl, file=f_ctl(1:nc_f_ctl), status='unknown')

      call skipcmnt(nu_ctl,cmnts2skip, nc_comments)
      f_sum = ' '
      read(nu_ctl,'(a)') f_sum
      call trim_c(f_sum, nc_f_sum)
      call get_lun(nu_sum)
      open(unit=nu_sum, file=f_sum(1:nc_f_sum), status='unknown')
      write(nu_sum,'(a)') '  Summary program for program ESMD2SMC'      

      call skipcmnt(nu_ctl,cmnts2skip, nc_comments)
      buf = ' '
      read(nu_ctl,'(a)') buf
      call trim_c(buf, nc_buf)
      call upstr(buf) 
      if (buf(1:1) .eq. 'Y') then
        raw_query = .true.
      else
        raw_query = .false.
      end if

      call skipcmnt(nu_ctl,cmnts2skip, nc_comments)
      read(nu_ctl,*) xfactr

      call skipcmnt(nu_ctl,cmnts2skip, nc_comments)

      loop over records: DO

        f_asc = ' '
        read(nu_ctl,'(a)') f_asc
        call trim_c(f_asc,nc_f_asc)
        f_asc_4 = ' '
        f_asc_4 = f_asc(1:4)
        call upstr(f_asc_4)
        if(f_asc_4 == 'STOP') EXIT
        write(nu_sum,'(a)') '  Processing file: '//f_asc(1:nc_f_asc)

        call get_lun(nu_asc)
        open(unit=nu_asc, file=f_asc(1:nc_f_asc), status='unknown')


        do i = 1, 23
          hdr_cmmnts(i) = ' '
          read(nu_asc,'(a)') hdr_cmmnts(i)
        end do

* Get sps (Assume evenly spaced; the ESMD routine raw_in allows for
* unevenly spaced).

        read(hdr_cmmnts(17),'(30x,f9.6)') dt
        write(nu_sum,'(1x,a,1x,f9.6)') ' dt = ', dt
      
* Get npts
        read(hdr_cmmnts(18),'(30x,i5)') n_ts  
        write(nu_sum,'(1x,a,1x,i5)') ' n_ts = ', n_ts
      
        allocate(ts(n_ts))


* Read any additional comments:

        nhdrs = 23
        read headers: DO i= 1, 40
          buf = ' '
          read(nu_asc,'(a)') buf
          IF (buf(1: 1) == '%') THEN
            nhdrs = nhdrs + 1
            call trim_c(buf, nc_buf)
            hdr_cmmnts(nhdrs) = ' '
            hdr_cmmnts(nhdrs)(1:nc_buf) = buf(1:nc_buf)
            IF (hdr_cmmnts(nhdrs)(1: 20) ==
     :           '                    ') nhdrs = nhdrs- 1
          ELSE
            call trim_c(buf, nc_buf)
            hdr_cmmnts(nhdrs) = ' '
            hdr_cmmnts(nhdrs)(1:nc_buf) = buf(1:nc_buf) ! header before data
            EXIT read headers
          ENDIF
        END DO read headers
 

C  assume evenly sampled
        READ (nu_asc, '(6(1X, E12.5))') (ts(i), i= 1, n_ts)


* Scale the time series:
        do i = 1, n_ts
          ts(i) = xfactr * ts(i)
        end do

        sps = 1.0/dt

        write(nu_sum,'(a,1x,i6,1x,f7.2)') '    n_ts, sps = ', n_ts, sps

        int_head(17) = n_ts
        
        real_head(2) = sps

        ncomments = 0
        ncomments = ncomments + 1
          comments(ncomments) = '|'
        do i = 1, nhdrs
          ncomments = ncomments + 1
          comments(ncomments) = '|'//hdr_cmmnts(i)
        end do
        ncomments = ncomments + 1
        comments(ncomments) = '|'
        ncomments = ncomments + 1
        comments(ncomments) = '| File '//f_asc(1:nc_f_asc)//
     : ' reformatted by program ESMD2SMC'
        ncomments = ncomments + 1
        comments(ncomments) = '| Data values scaled by the factor '
        call trim_c(comments(ncomments), nc_c)
        write(comments(ncomments)(nc_c+1:nc_c+11),'(0p,1x,e10.3)')
     :  xfactr
        ncomments = ncomments + 1
        comments(ncomments) = '|'

        int_head(16) = ncomments

        f_smc = ' '
        f_smc = f_asc(1:nc_f_asc)//'.smc'
        call trim_c(f_smc,nc_f_smc)

        write(*,'(a)') ' Writing file '//f_smc(1:nc_f_smc)

        precision = ' '
        precision = 'STANDARD'
        int_head(47) = int_head(1)

        call smcwrite(f_smc,       precision,
     :                 ts, char_head, 0, 
     :              int_head, real_head, comments)
     
        close(nu_asc)
      
        deallocate(ts)

      END DO loop over records

      close(nu_ctl)
      close(nu_sum)

      stop
      end

      include '\forprogs\skip.for'
      include '\forprogs\distaz.for'
      include '\forprogs\smcwrite.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\upstr.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\mnmaxidx.for'
      include '\forprogs\skipcmnt.for'

