       Program SCE2SMC2

*  Reads in data files from S. Cal. Edison and reformats them
*  into SMC format (the format used on the CD-ROM)

*  This version reads in the second format (in which the Devers
*  data from the Landers earthquake was supplied)

*  Various header parameters are read from a file in namelist format

*  Note: In this version I must make sure that the order of the SCE files
*  specified in the namelist file is in agreement with the component
*  information.

*  To compile:
*    fl/Fs sce2smc2.for doy wcc wcchr

*  Dates:   04/12/93 - Written by D. Boore (modified from
*                      SCEToSMC.FOR)
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats

      character precision*8
      

      real  sps, orient_v(3), orient_h(3), 
     :      eqlat, eqlong, stalat, stalong, amag, rnull,
     :      freqins, dampins, rhead(50)

      integer iyr, imon, iday, ihr, isec, iaccel(13000),
     :        inscode, ncomments, naccel, inull, idoy, ihead(48)

      character stacode*4, fnameout*12, fnamesce(3)*12, fnamein*12,
     :          hour*1, eqname*20, staname*20, compname*1(3), buffer*80,
     :          comments(4)*80

      namelist/input/ fnamesce, eqname, staname, stacode,
     :                iyr, imon, iday, ihr, imin, isec, 
     :                inscode, ncomments, inull,
     :                sps, orient_v, orient_h, compname,
     :                eqlat, eqlong, stalat, stalong, amag, rnull

* Open input file and read information:

      write(*, '(a\)') '  Enter name of input file:'
      read(*, '(a)') fnamein
      open(unit=10, file=fnamein, status='unknown')

* Now use namelist to read the parameters:
      read(10, NML=input)
* Echo to screen:
      write(*, NML=input)

* Close input file:
      close(unit=10)

* Calculate doy and hour character:

      hr = ihr
      call WCCHR(hr, hour, 1, icstr2)

      call DOY(iyr, imon, iday, idoy, istat)

* write results to screen:
      write(*, '(a,i2, 2a)') ' For ihr= ', ihr, ' hour= ', hour
      write(*, '(a,i4, i2, i2, a, i3)') ' For year, mon, day= ', 
     :      iyr, imon, iday, ' doy= ', idoy

* Loop over the three components (make sure that the filenames and component
* information in the namelist file are consistent):

      do icomp = 1, 3

* Open a SCE file:
      open(unit=20, file=fnamesce(icomp), status='unknown')

* Construct the output file name:

         write(fnameout(1:3), '(i3.3)') idoy
         fnameout(4:4) = hour
         write(fnameout(5:6), '(i2.2)') imin
         fnameout(7:8) = stacode(1:2)
         fnameout(9:9) = '.'
         fnameout(10:11) = stacode(3:4)
         fnameout(12:12) = compname(icomp)

* Open output file:
         open(unit=30, file=fnameout, status='unknown')

* Write name to screen:
         write(*, '(2a)') ' Output file name: ', fnameout

* Write headers:

* First write the 11 lines of comments:

         write(30, '(a)') '*'
         write(30, '(a)') '*'
         write(30, '(a)') stacode
         write(30, '(5x,i4,2x,i2,2x,i2,4x,i2,i2,1x,a)') 
     :              iyr, imon, iday, ihr, imin, eqname
         write(30, '(a,6x,f3.1)') 'Moment Mag=', amag
         write(30, '(2a,t42,a,i3)') 'station = ', staname, 
     :                            'component= ', int(orient_h(icomp)) 
         write(30, '(a,t34,a)') 'epicentral dist =','pk acc ='
         write(30, '(a, t22, a)') 'inst type=DSA', 'data source = SCE'
         write(30, '(a)') '*'
         write(30, '(a)') '*'
         write(30, '(a)') '*'
          
* Read 4 lines of header information from SCE:

         do i = 1, 4
            comments(i) = ' '
            read(20, '(a)') comments(i)
         end do

* Read component information:

         read(20, 9966) naccel, dt, fact, freqins, dumd
9966     format(2x,i5,t18,f5.3,t25,f9.3,t39,f6.3,t49,f6.3)

         sps = 1.0/dt
         dampins = dumd/100.0
         if (fact .lt. 0.0) then
           scalefact = 980.0/abs(fact)
         else
           scalefact = 980.0*abs(fact)
         endif

* Now write the integer header block:
* First fill with null values:
         do i = 1, 48
           ihead(i) = inull
         end do

         ihead(1) = inull
         ihead(2) = iyr
         ihead(3) = idoy
         ihead(4) = ihr
         ihead(5) = imin
         ihead(6) = isec
         ihead(11) = 3
         ihead(13) = orient_v(icomp)
         ihead(14) = orient_h(icomp)
         ihead(15) = inscode
         ihead(16) = ncomments
         ihead(17) = naccel

         write(30, '(8I10)') (ihead(i), i=1,48)

* Now write the real header block:
* First fill with null values:
         do i = 1, 50
           rhead(i) = rnull
         end do

         rhead(1) = rnull
         rhead(2) = sps
         rhead(3) = eqlat
         rhead(4) = eqlong
         rhead(6) = amag
         rhead(11) = stalat
         rhead(12) = stalong
         rhead(22) = freqins
         rhead(23) = dampins

         write(30, '(5E15.7)') (rhead(i), i=1,50)

* Write the comments:

         do i = 1, ncomments
            write(30, '(2a)') '|', comments(i)
         end do

* Read the acceleration values from the SCE file, scale to cm/s^2, and write.

         read(20, '(10i7)') (iaccel(j), j = 1, naccel)
         write(30, '(8(1pe10.4e1))') 
     :         (scalefact*iaccel(j), j = 1, naccel)
         
* That should be it; close the SCE and output files and 
* loop back for another component.

         close(unit=30)
         close(unit=20)
      end do

      stop
      end

               