* ---------------------------------------------------------------- CGS2smc
      Program CGS2smc

* Convert CGS V1, V2, or V3 files to USGS SMC format (RS2 format for V3)

* Note that the V1 data are primarily from the Hector Mine data and are
* evenly sampled.  The CGS format for these data ARE NOT the same as specified
* in OSMS 85-03

* The program has not been modified to deal with unevenly sampled time series.
* For these (and for files conforming to the format in OSMS 85-03) use bap as
* follows:
*          v2s outfile. = infile
*          bap outfmt.usx, outfmt=smc, interp(f)
* Use the latter if the original file was unevenly sampled.  "x" is the file
* number assigned by v2s.   This command has the default sample rate = 200 sps.


* Sample control file:
*Control file for program CGS2SMC
*Quake_Code
* 355
*Quake_Name
* Northridge mainshock
*Eq Hypocenter:
* 34.209, -118.541
*Moment Magnitude:
* 6.7
*Volume 1, 2, or 3?
* 2
*Should include sta_code (0 = no, 1 = yes):
* 1
*Station Filenames:
*ALHAMBRA.V2  970
*ANACAPA.V2   205
*ANAV_VLY.V2  1156
* stop

* Dates: 10/25/00 - Written by D. Boore
*        12/22/00 - Increased dimensions of ts and comments,
*                   and now write CDMG text headers as comments
*        12/29/00 - Use dynamically allocatable array for ts
*        03/13/01 - Allow for up to 99 channels
*        03/18/01 - New program, allowing for v1, v2 or v3 files
*        06/12/01 - Use new version of rs2write (more calling parameters)
*        02/19/02 - Get name of control file as default
*        04/04/02 - Increased I format in writing n_ts to screen
*        07/06/04 - A few small changes to compile using LF95
*        11/07/05 - Changed from "CDMG" to "CGS" in the name of 
*                   program and control file  
*        07/17/06 - Make it work with most recent CGS RAW files   
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats
* ###  NOT FINISHED:  RAW IS GIVEN IN UNEQUALLY SAMPLE T, A PAIRS

      character thead_smc(11)*80, comments(500)*80 
      character precision*8

      integer ihead_smc(48)
      real rhead_smc(50)

      character thead_csmip(30)*80, c_lat*1, c_long*1, c_ncomp*2
      integer ihead_csmip(100), n_ts(3)
      real rhead_csmip(100)
      real damping(5), per(100), 
     :     fas(100), psrv(100,5), sd(100,5), rv(100,5), aa(100,5), 
     :     ttsd(100,5), ttrv(100,5), ttaa(100,5)

      real ts(:,:)
      allocatable :: ts

      character f_ctl*40, f_in*40, f_out*40, endchn*2
      character temp_c*8, temp_staid*5, quake_name*54, buf*80
      character buf_upper*4
      logical f_ctl_exist

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr = cgs2smc.ctl): '
        read(*, '(a)') f_ctl
        if (f_ctl .eq. ' ') f_ctl = 'cgs2smc.ctl'
        call trim_c(f_ctl,nc_f_ctl)
        inquire(file=f_ctl(1:nc_f_ctl), exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_ctl(1:nc_f_ctl),status='unknown')

      call skip(nu_ctl,2)
      read(nu_ctl,*) iquake_code

      call skip(nu_ctl,1)
      buf = ' '
      read(nu_ctl, '(a)') buf
      call trim_c(buf,nc_buf)
      nc_qn = min0(nc_buf, 54)
      quake_name = ' '
      quake_name = buf(1:nc_qn)
      write(*,'(2a)') ' quake_name: ', quake_name(1:nc_qn)

      call skip(nu_ctl,1)
      read(nu_ctl, *) eqlat, eqlong

      call skip(nu_ctl,1)
      read(nu_ctl, *) amommag

      call skip(nu_ctl,1)
      read(nu_ctl, *) ivol

      call skip(nu_ctl,1)
      read(nu_ctl, *) i_get_sta_code

      call skip(nu_ctl,1)
     
1234  continue

      buf = ' '
      buf_upper = ' '
      read(nu_ctl,'(a)') buf
      call trim_c(buf, nc_buf)
      buf_upper = buf(1:4)
      call upstr(buf_upper)
      if(buf_upper(1:4).eq.'STOP') then
        close(nu_ctl)
        stop
      end if

      f_in = ' '
      call RCC (1,buf,nc_buf,f_in,nc_f_in,ibgn,iend)
      if (i_get_sta_code .eq. 1) then
        call RCI (2,buf,nc_buf,ista_code,ibgn,iend,ISTAT)
      else
        ista_code = 0
      end if

      call get_lun(nu_in)
      open(unit=nu_in,file=f_in(1:nc_f_in),status='unknown')

* First get n_ts for array allocation:

* Read text headers:
      if (ivol .eq. 1) then
        nthead_csmip = 13
        nrhead_csmip = 50
        ith_offset = -1
      else if (ivol .eq. 2) then
        nthead_csmip = 25
        nrhead_csmip = 100
        ith_offset = 0
      else if (ivol .eq. 3) then
        nthead_csmip = 30
        nrhead_csmip = 100
        ith_offset = +1
      else
        write(*,'(a,i5,a)') ' ivol = ', ivol, 
     :                      '; not 1, 2, or 3--- QUITTING!!!'
        stop
      end if
      do i = 1, nthead_csmip
        thead_csmip(i) = ' '
        read(nu_in,'(a)', end=666) thead_csmip(i)
      end do

* Read integer headers:
      read(nu_in,'(16i5)') (ihead_csmip(i), i=1, 100)

* Close the file:
      close(nu_in)

* Get size of arrays to be allocated (and assume that it is the same for all 
* channels!):

      do i = 1, 3
        n_ts(i) = 0
      end do

      if (ivol .eq. 1) then
        n_ts(1) = ihead_csmip(28)       ! should be acceleration
        n_gm = 1
      else if (ivol .eq. 2) then
        n_ts(1) = ihead_csmip(53)       ! should be acceleration
        n_ts(2) = ihead_csmip(64)       ! should be velocity
        n_ts(3) = ihead_csmip(66)       ! should be displacement
        n_gm = 3
      else if (ivol .eq. 3) then
        n_per =  ihead_csmip(68)
        n_damp = ihead_csmip(69)
        n_gm = 1
      end if

      if (ivol .lt. 3) then


        n_ts_max = max0(n_ts(1), n_ts(2), n_ts(3)) 
*        write(*,'(a)') '  n_ts(1..3), n_ts_max = '
*        write(*,*) (n_ts(i), i =1 ,3),  n_ts_max
        
* To be safe, add 50% more to the array:
        n_ts_max = 1.5*float(n_ts_max)

* Allocate array:
        allocate (ts(n_ts_max,n_gm))

      end if

* Now open the file and extract the data:

      open(unit=nu_in,file=f_in(1:nc_f_in),status='unknown')

* Loop over channels:
  
      nchn = 0

2000  continue


* Read text headers (again):
      do i = 1, nthead_csmip
        thead_csmip(i) = ' '
        read(nu_in,'(a)', end=666) thead_csmip(i)
      end do

      nchn = nchn + 1

* Check for more than 99 channels:
      if (nchn .gt. 99) then
         write(*,'(a,1x,i5,a)') 
     :       ' !!! nchn = ', nchn, ', > 99; Move to next file !!!'
         goto 666
      end if

* Read integer headers:
      read(nu_in,'(16i5)') (ihead_csmip(i), i=1, 100)

* Read real headers:

      read(nu_in, '(8f10.3)') (rhead_csmip(i), i=1, nrhead_csmip)

* Read time series or spectra:

      if (ivol .eq. 1) then
        call skip(nu_in,1)   ! could get npts from this line
        write(*, '(a,1x,i6)') ' Reading data, n_ts(1) = ', n_ts(1)
        read(nu_in,'(8f9.6)') (ts(j,1), j = 1, n_ts(1))

        do j = 1, n_ts(1)
          ts(j,1) = 981.0*ts(j,1)   ! convert from g to cm/s/s
        end do

      else if (ivol .eq. 2) then
        do i = 1, n_gm
          call skip(nu_in,1)   ! could get npts from this line
          read(nu_in,'(8f10.3)') (ts(j,i), j = 1, n_ts(i))
        end do
      else if (ivol .eq. 3) then
        read(nu_in, '(8f10.3)') (damping(j),j=1, n_damp)
        read(nu_in, '(8f10.3)') (per(j),j=1, 100)  ! read 0.0's to position rec.
        call skip(nu_in,1)
        read(nu_in, '(8e10.3)') (fas(j),j=1, 100)  ! read 0.0's to position rec.
        do j = 1, 100
          fas(j) = 2.54 * fas(j)   ! convert from inch/sec to cm/sec
        end do           
        do i = 1, n_damp        
          call skip(nu_in,1)
          read(nu_in, '(8e10.3)') (sd(j,i),j=1, 100)
          read(nu_in, '(8e10.3)') (rv(j,i),j=1, 100) 
          read(nu_in, '(8e10.3)') (aa(j,i),j=1, 100) 
          read(nu_in, '(8e10.3)') (psrv(j,i),j=1, 100)
          read(nu_in, '(8e10.3)') (ttsd(j,i),j=1, 100)
          read(nu_in, '(8e10.3)') (ttrv(j,i),j=1, 100)
          read(nu_in, '(8e10.3)') (ttaa(j,i),j=1, 100)
          do j = 1, 100
            sd(j,i) = 2.54 * sd(j,i)   ! convert to metric
            rv(j,i) = 2.54 * rv(j,i)   ! convert to metric
            psrv(j,i) = 2.54 * psrv(j,i)   ! convert to metric
            aa(j,i) = 981.0 * aa(j,i)   ! convert to metric
          end do
        end do  ! end loop over dampings            
      end if

* Set up text headers:
      do i = 1, 11
        thead_smc(i) = ' '
      end do
      thead_smc(2) = '*'
      thead_smc(3) = thead_csmip(6+ith_offset)(13:17) ! Not official SMC format
      thead_smc(4)(1:25) = thead_csmip(4+ith_offset)(1:25) 
      thead_smc(4)(27:80) = quake_name(1:nc_qn)
      thead_smc(5) = 
     :    'Moment Mag=          Ms=          Ml='
      write(thead_smc(5)(12:20),'(f9.2)') amommag
      thead_smc(6) = 
     :    'station =                                component='
      thead_smc(6)(11:40) = thead_csmip(7+ith_offset)(1:30)

      if (ihead_csmip(27) .gt. 360) then      ! assume vertical
        thead_smc(6)(56:57) = 'UP'
      else
        write(thead_smc(6)(53:57),'(i5)') ihead_csmip(27)
      end if
      thead_smc(7) = 
     :    'epicentral dist ='
* Extract station coordinates and compute epicentral distance:
      read(thead_csmip(6+ith_offset)(21:26),'(f6.3)') stalat
      read(thead_csmip(6+ith_offset)(30:36),'(f7.3)') stalong
      c_lat = thead_csmip(6+ith_offset)(27:27)
      c_long = thead_csmip(6+ith_offset)(37:37)
      call upstr(c_lat)
      if (c_lat .eq. 'S') stalat = -abs(stalat)
      call upstr(c_long)
      if (c_long .eq. 'W') stalong = -abs(stalong)
      call distaz( -1.0, eqlat,eqlong,stalat,stalong,
     :    rdeg, rkm, az, baz)
      write(thead_smc(7)(18:26),'(f9.1)') rkm
      thead_smc(8) = 
     :    'inst type=           data source = CSMIP'
               
      temp_c = ' '
      temp_c = thead_csmip(6+ith_offset)(40:47) 
      call trim_c(temp_c,nc_tc)
      if (nc_tc .gt. 5) nc_tc = 5
      thead_smc(8)(11:11+nc_tc-1) = temp_c(1:nc_tc)

      do i = 9, 11
        thead_smc(i) = '*'
      end do

* Set up comments:
      comments(1) = '|'
      comments(2) = '| CSMIP file '//f_in
      if (ivol .ne. 3) then
        comments(3) = '| Reformatted to SMC format, using CGS2smc'
      else
        comments(3) = '| Reformatted to RS2 format, using CGS2smc'
      end if
      comments(4) = '|'
      comments(5) = '| Here follow the CSMIP text headers:'
      comments(6) = '|'
      ncomments = 6
* Now add CSMIP text headers as comments:
      do i = 1, nthead_csmip
        comments(i+ncomments) = '| '//thead_csmip(i)(1:78)
      end do
      ncomments = ncomments + nthead_csmip

* Set up integer headers independent of type of motion:
      do i = 1, 48
        ihead_smc(i) = -32768
      end do

      read(thead_csmip(6+ith_offset)(54:57),'(i4)') ihead_smc(8)

      ihead_smc(9) = nchn

      if (ihead_csmip(27) .gt. 360) then      ! assume vertical
        ihead_smc(13) = 0
        ihead_smc(14) = 0
      else
        ihead_smc(13) = 90
        ihead_smc(14) = ihead_csmip(27)
      end if

      ihead_smc(16) = ncomments

      temp_staid = ' '
      temp_staid = thead_csmip(6+ith_offset)(13:17)
      call notnumrc(temp_staid, 5, iflag)
      if (iflag .eq. 0) then
        read(temp_staid,'(i5)') ihead_smc(30)
      end if

      ihead_smc(31) = 1

      ihead_smc(40) = iquake_code
      ihead_smc(41) = ista_code
      
      precision = ' '
      precision = 'STANDARD'
      ihead_smc(47) = ihead_smc(1)

* Set up real headers independent of type of motion:
      do i = 1, 50
        rhead_smc(i) = 1.7e+38
      end do

      if (ivol .eq. 1) then
        rhead_smc(2) = float(ihead_csmip(6)) ! OK for V1 for HM99
      else
        rhead_smc(2) = 1.0/rhead_csmip(61)
      end if
      rhead_smc(3) = eqlat
      rhead_smc(4) = eqlong
      rhead_smc(6) = amommag
      rhead_smc(11) = stalat
      rhead_smc(12) = stalong
      rhead_smc(17) = rkm
      rhead_smc(18) = az
      if (rhead_csmip(1) .ne. 0.0) then
        rhead_smc(22) = 1.0/rhead_csmip(1)
      end if
      rhead_smc(23) = rhead_csmip(2)
      rhead_smc(24) = rhead_csmip(6)
      if ( ivol .gt. 1) then
        rhead_smc(33) = rhead_csmip(62) - rhead_csmip(63)
        rhead_smc(34) = rhead_csmip(62)
        rhead_smc(35) = rhead_csmip(58) - rhead_csmip(59)
        rhead_smc(36) = rhead_csmip(58)
      end if

* Now do motion-specific things (define filenames, using  v2s scheme
* .as1, .as2, .as3, etc; fill rhead(29),..,rhead(32)
* with peak values and times, fill ihead(17) with number of time series 
* values

      do i = 1, n_gm

        ihead_smc(17) = n_ts(i)
        ihead_smc(32) = n_ts(i)
      
* Get peak motions:
      
        if (ivol .ne. 3) then
          call mnmaxidx(ts(1,i), 1, ihead_smc(17), 1,
     :             ymin, ymax, indx_min, indx_max) 
          tmin = float(indx_min-1)/rhead_smc(2)
          tmax = float(indx_max-1)/rhead_smc(2)
          rhead_smc(29) = tmax
          rhead_smc(30) = ymax
          rhead_smc(31) = tmin
          rhead_smc(32) = ymin
        end if

        f_out = ' '
        nstem = index(f_in(1:nc_f_in),'.') - 1
        write(c_ncomp,'(i2.2)') nchn
        if (ivol .eq. 1) then
          f_out = f_in(1:nstem)//'.u'//c_ncomp
          itype = 1
          call SMCWrite(f_out, precision,
     :                  ts(1,i), thead_smc, itype, 
     :                    ihead_smc, rhead_smc, comments)
        else if (ivol .eq. 2) then
          if( i .eq. 1) then
            f_out = f_in(1:nstem)//'.a'//c_ncomp
            itype = 2
          else if ( i .eq. 2) then
            f_out = f_in(1:nstem)//'.v'//c_ncomp
            itype = 3
          else
            f_out = f_in(1:nstem)//'.d'//c_ncomp
            itype = 4
          end if
          call SMCWrite(f_out, precision,
     :                  ts(1,i), thead_smc, itype, 
     :                    ihead_smc, rhead_smc, comments)
        else if (ivol .eq. 3) then
* Write FAS and response spectra
          f_out = f_in(1:nstem)//'.r'//c_ncomp
          itflag = 0
          call rs2write(f_out, damping, n_damp, per, n_per,
     :                  sd, rv, aa, 
     :                  thead_smc, ihead_smc, rhead_smc, comments,
     :                  itflag, tprd, tprv, tpaa)
        end if

      end do

*  check for end-of-channel marker:
      endchn = ' '
      read(nu_in, '(a)') endchn

      if (endchn .ne. '/&') then
         write(*,'(a)') ' Problem with endchn, ne /&, quitting'
         stop
      end if

*  go back for a new channel:

      go to 2000

666   continue
      close(nu_in)

      if (ivol .lt. 3) then
        deallocate (ts)
      end if

      go to 1234

      end
* ---------------------------------------------------------------- CGS2smc

      include '\forprogs\notnumrc.for'
      include '\forprogs\smcwrite.for'
      include '\forprogs\rs2write.for'
      include '\forprogs\upstr.for'
      include '\forprogs\skip.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\distaz.for'
      include '\forprogs\mnmaxidx.for'
      include '\forprogs\rc_subs.for'

          