      Program evt2smc
      
* Converts evt files into smc files.  This program is
* a slight modification of a program by C. Stephens.


*! Control file for evt2smc
*!Quake_Name
* Zemmouri
*!Eq Hypocenter (lat, long, north, east positive):
*36.83, 3.65 
*! Eq Depth
* 10.0
*!Moment Magnitude:
* 6.8
*!file 
*AK002.EVT
*AO003.EVT
*AO008.EVT
*AO034.EVT
*AS004.EVT
*BB014.EVT
*BC044.EVT
*stop      

* Dates: 06/03/09 - Written by D. Boore; a slight modification 
*                   of the program evt2smc by C. D. Stephens

        character(len=256) :: fname, pfile = ' '
	character(len=80) :: arg
	integer :: iargc
	integer :: nargs, iarg
        integer :: getarg
	logical :: exists
	logical :: verbose = .false.
        integer :: ialt_flag
        
      real eqlat, eqlong, eqdepth, eqmag

      character f_ctl*120, f_evt*120, f_smc*120, 
     :          buf*80, buf4*4, eqname*40
      character hdr_cmmnts(100)*79
      logical f_ctl_exist

 
      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr = evt2smc.ctl): '
        read(*, '(a)') f_ctl
        if (f_ctl(1:4) .eq. '    ') f_ctl = 'evt2smc.ctl'
        call trim_c(f_ctl, nc_f_ctl)
        inquire(file=f_ctl(1:nc_f_ctl), exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do
      call get_lun(nu_ctl)
      open(unit=nu_ctl, file=f_ctl(1:nc_f_ctl), status='unknown')

      call skipcmnt(nu_ctl, hdr_cmmnts, n_hdr_cmmnts)
      eqname = ' '
      read(nu_ctl,'(a)') eqname
      call trim_c(eqname, nc_eqname)

      call skipcmnt(nu_ctl, hdr_cmmnts, n_hdr_cmmnts)
      read(nu_ctl,*) eqlat, eqlong
      
      call skipcmnt(nu_ctl, hdr_cmmnts, n_hdr_cmmnts)
      read(nu_ctl,*) eqdepth
      
      call skipcmnt(nu_ctl, hdr_cmmnts, n_hdr_cmmnts)
      read(nu_ctl,*) eqmag
         
! NOTE:  eqlat, eqlong, eqdepth, eqmag not used in this version

      call skipcmnt(nu_ctl, hdr_cmmnts, n_hdr_cmmnts)
 
1234  continue

      f_evt = ' '
      read(nu_ctl,'(a)') f_evt
      call trim_c(f_evt,nc_f_evt)
      buf4 = ' '
      buf4 = f_evt(1:4)
      call upstr(buf4)
      if(buf4 .eq. 'STOP') then
        close(nu_ctl)
        stop
      end if
      
      write(*,'(2a)') '  Processing file: ', f_evt(1:nc_f_evt)
  
      inquire(file=f_evt(1:nc_f_evt),exist=exists)
      if (.not. exists) then
	 print *,' file '//f_evt(1:nc_f_evt)//
     :      ' does not exist, skipping to the next file.'
         go to 1234
      end if

c  get the filesize

        inquire(file=f_evt(1:nc_f_evt),flen=isize)
        if (verbose) print *, 'File size is',isize,' bytes'

c  load the .evt file

        call proc_file(isize, f_evt(1:nc_f_evt), pfile)

        go to 1234
        
	end


        subroutine proc_file(isize, fname, pfile)

	integer isize
        character(len=*) fname, pfile

c    define array for time series data

	real*4, allocatable, dimension(:) :: seis	! de-muxed time series of all recorded channels

c    define dynamic (automatic) array for contents of .evt file

        character(len=isize) :: io_buff

c    include files
	
	include 'evt2smc_headers.txt'

c    external functions

	integer*4 load_evt_header
	integer*4 load_evt_seis
        character(len=5) :: kmi_inst_type

c    local variables

        integer*4 year, month, day_of_month, day_of_year
        integer*4 hour, minute, second
	integer*4 start_time
	integer*2 start_time_msec
	integer*2 n_data_bytes, n_active_channels
        integer :: station_number
        integer :: gps_roll
	integer :: sensor_serial_num
	integer*2 header_version
	byte instr_code
	integer*2 dsp_blk_ver
        character*5 instr_type
	character(len=45) :: data_source = 'USGS'
	character(len=30) :: station_name = ' '
	character(len=60) :: smcfile
	character(len=1) :: ch_id
	logical :: force = .true.	! force station longitudes to be west
	integer :: n_corrupt_segments
	integer :: lune = 20
	character(len=80) :: comment = ' '

	character*8 proc_date
	character*10 proc_time
	character*5 proc_tzone
	integer proc_val(8)

	character(len=256) :: eq_parm_rec

c -- main routine -----------------------------------------------------------

c	pfile = 'hector.prm'

	call date_and_time(proc_date, proc_time, proc_tzone, proc_val)

c  open and read contents of the evt file

	open(unit=2,file=fname,access='direct',form='unformatted',
     *          recl=isize, iostat=ios)
	if (ios .ne. 0) then
	  print *, 'Error opening file: ', trim(fname)
	  go to 90
	endif

        read(2,rec=1,iostat=ios) io_buff
	if (ios .ne. 0) then
	  print *, 'Error reading io_buff, ios=', ios
	  close(unit=2)
	  go to 90
	endif

	close(unit=2)

	if (.false.) then
	  i = 0
	  do while (i .lt. isize)
	    i = i + 1
            write(6,'(i10,z3.2)') i, io_buff(i:i)
	  enddo
	endif

c  open a scratch file to log errors to include in smc files

	open(unit=lune, status='scratch', access='sequential')

c -- load the .evt file header

        koff = 0	! initial offset in io_buffer

        ires = load_evt_header(io_buff, isize, koff,
     *    kff_tag, kff_file_descr,
     *	  misc_ro_parms, timing_ro_parms, chan_ro_parms,
     *    stream_ro_parms, rw_parms, timing_rw_parms, chan_rw_parms,
     *    stream_rw_parms, voter_info, modem_rw_parms,
     *	  frame_header)

c -- report selected header parameters

	start_time = stream_ro_parms.start_time

	start_time_msec = stream_ro_parms.start_time_msec
	call altus_time(start_time, year, month, day_of_month,
     *          day_of_year, hour, minute, second, gps_roll)

	write(6,'(" Start time:",
     *          i5,2(1h/,i2.2),2h (,i3.3,2h) ,2(i2.2,1h:),i2.2,f4.3)')
     *          year, month, day_of_month, day_of_year,
     *          hour, minute, second, float(start_time_msec)

	if (timing_ro_parms.clock_source .eq. 0) then
	    print *, 'clock source = RTC'
	else if (timing_ro_parms.clock_source .eq. 1) then
	    print *, 'clock source = keyboard'
	else if (timing_ro_parms.clock_source .eq. 2) then
	    print *, 'clock source = External sync'
	else if (timing_ro_parms.clock_source .eq. 3) then
	    print *, 'clock source = GPS'
	endif
	if (gps_roll .eq. 1)
     *      print *, 'Correction made for GPS rollover'

	print *, 'Sample rate =', stream_rw_parms.sps

c -- load time series data from io_buff

c    note that de-muxed data for all channels is stored in the 1-D array seis, and that
c    the offset to the start of the time series for channel ichan is (ichan-1)*nscans

        nscans = stream_ro_parms.nscans         ! number of samples/channel

        nsamples = stream_ro_parms.nscans * rw_parms.nchannels  ! total number of samples for all channels

        allocate(seis(nsamples))         ! all recorded channels

	ires = load_evt_seis(io_buff, isize, koff,
     *	  seis, nsamples, lune, n_corrupt_segments,
     *    kff_tag, kff_file_descr,
     *	  misc_ro_parms, timing_ro_parms, chan_ro_parms,
     *    stream_ro_parms, rw_parms, timing_rw_parms, chan_rw_parms,
     *    stream_rw_parms, voter_info, modem_rw_parms,
     *    frame_header)

c -- read earthquake parameters from file

	if (pfile .ne. ' ') then
	  open(unit=4, file=pfile, iostat=ios)
	  if (ios .ne. 0) then
	    print *, 'Could not open earthquake parameter file: ',
     *		trim(pfile)
	  else
	    read(4,'(a)') eq_parm_rec
	    read(eq_parm_rec,
     *         '(i4,2(1x,i2),1x,2(i2,1x),f6.0,f9.4,f10.4,f8.2,
     *          4f5.2,e10.2,t81,a54)',iostat=ios)
     *		eq_yr, eq_mo, eq_da, eq_hr, eq_mn, eq_sec,
     *		eq_lat, eq_lon, eq_dep,
     *		eq_mw, eq_ms, eq_ml, eq_moth, eq_mom, eq_name
	    if (ios .ne. 0) then
              print *, 'Error reading earthquake parameter file: ',
     *		trim(pfile)
	      eq_yr = 0
	      eq_mo = 0
	      eq_da = 0
	      eq_hr = 0
	      eq_mn = 0
	      eq_sec = R_NULL
	      eq_lat = R_NULL
	      eq_lon = R_NULL
	      eq_dep = R_NULL
	      eq_mw = R_NULL
	      eq_ms = R_NULL
	      eq_ml = R_NULL
	      eq_moth = R_NULL
	      eq_mom = R_NULL
	    else	! set undefined parameters, other than OT, to null
              if (eq_parm_rec(24:32) .eq. ' ') eq_lat  = R_NULL
              if (eq_parm_rec(33:42) .eq. ' ') eq_lon  = R_NULL
              if (eq_parm_rec(43:50) .eq. ' ') eq_dep  = R_NULL
              if (eq_parm_rec(51:55) .eq. ' ') eq_mw  = R_NULL
              if (eq_parm_rec(56:60) .eq. ' ') eq_ms  = R_NULL
              if (eq_parm_rec(61:65) .eq. ' ') eq_ml  = R_NULL
              if (eq_parm_rec(66:70) .eq. ' ') eq_moth  = R_NULL
              if (eq_parm_rec(71:80) .eq. ' ') eq_mom  = R_NULL
	    endif
	    close(unit=4)
	  endif
	endif

c -- prepare to write out smc files

c    first, fill in global parameters in headers:

c    start time of first sample

	i_head(2) = year
	i_head(3) = day_of_year
	i_head(4) = hour
	i_head(5) = minute
	i_head(6) = second
	i_head(7) = start_time_msec

c    misc integer header parameters

	i_head(8) = kff_tag.id			! recorder S/N

	i_head(16) = 3				! number of comment records
        i_head(17) = stream_ro_parms.nscans	! number of data samples
	if (n_corrupt_segments .gt. 0) then
	  i_head(18) = 1			! set problem flag
	  i_head(16) = i_head(16) + n_corrupt_segments	! increase number of comment records
	endif

	ie = index(rw_parms.stn_id,char(0)) - 1
        if (ie .gt. 0) read(rw_parms.stn_id(1:ie),'(i4)',iostat=ios)
     *    i_head(30)    ! station_number
        if (ios .ne. 0) then
           print *, 'Warning - invalid station number: ',
     *       rw_parms.stn_id
           i_head(30) = I_NULL
        endif

	i_head(31) = 1				! first recorded sample
        i_head(32) = stream_ro_parms.nscans	! last recorded sample

	i_head(48) = timing_ro_parms.clock_source
	  if (gps_roll .eq. 1) i_head(48) = -i_head(48)

c    real header parameters

	r_head(2) = stream_rw_parms.sps		! sample rate

c    earthquake parameters

	if (eq_lat .ne. R_NULL) r_head(3) = eq_lat
	if (eq_lon .ne. R_NULL) r_head(4) = eq_lon
	if (eq_dep .ne. R_NULL) r_head(5) = eq_dep
	if (eq_mw .ne. R_NULL) r_head(6) = eq_mw
	if (eq_ms .ne. R_NULL) r_head(7) = eq_ms
	if (eq_ml .ne. R_NULL) r_head(8) = eq_ml
	if (eq_moth .ne. R_NULL) r_head(9) = eq_moth
	if (eq_mom .ne. R_NULL) r_head(10) = eq_mom

c    station location

	if (rw_parms.latitude .ne. 0.) then
	  r_head(11) = rw_parms.latitude	! N+
	else
	  print *, 'Station latitude undefined'
	endif

	if (rw_parms.longitude .ne. 0.) then
	  r_head(12) = rw_parms.longitude	! E+
	else
	  print *, 'Station longitude undefined'
	endif
	if (force .and. (r_head(12) .ne. R_NULL)) 
     *		r_head(12) = -abs(r_head(12))

	if (rw_parms.elevation .ne. 0.) r_head(13) = rw_parms.elevation	! m

c    distance and azimuth

	if (r_head(3) .ne. R_NULL .and. r_head(4) .ne. R_NULL
     *	  .and. r_head(11) .ne. R_NULL .and. r_head(12) .ne. R_NULL) then
	  call geocen(r_head(11),r_head(12),r_head(3),r_head(4),
     *          dist,az,baz)
	  r_head(17) = dist
	  r_head(18) = az
	endif
	
c    global text header parameters

c      text header 1: time series data type

	idata_type = 1

	select case (idata_type)

	case (0)
	  t_head(1) = '0 UNKNOWN'

	case (1)
	  t_head(1) = '1 UNCORRECTED ACCELEROGRAM'

	case (2)
	  t_head(1) = '2 CORRECTED ACCELEROGRAM'

	case (3)
	  t_head(1) = '3 VELOCITY'

	case (4)
	  t_head(1) = '4 DISPLACEMENT'

	case default
	  t_head(1) = '1 UNCORRECTED ACCELEROGRAM'

	end select

c     text header 2:

	t_head(2) = '*'

c     text header 3: station number

	ie = index(rw_parms.stn_id,char(0)) - 1
	if (ie .gt. 0) then
          read(rw_parms.stn_id(1:ie),'(i4)',iostat=ios) station_number
          if (ios .eq. 0) then
            write(t_head(3)(1:4),'(i4.4)') station_number
            i_head(30) = station_number
          else
            print *, 'Warning - invalid station number: ',
     *        rw_parms.stn_id
            t_head(3)(1:ie) = rw_parms.stn_id(1:ie)
            i_head(30) = I_NULL
          endif
	else
	  t_head(3) = '*'
	endif

c     text header 4: earthquake origin time and name

        if (eq_yr .ne. 0) then
	  write(t_head(4),'(5x,i4,2i4.2,4x,2i2.2)')
     *          eq_yr, eq_mo, eq_da, eq_hr, eq_mn
	endif

        if (eq_name .ne. ' ') then
          write (t_head(4)(27:),'(a)') trim(eq_name)
	endif

c     text header 5: magnitudes and seismic moment

	if (r_head(6) .ne. R_NULL)
     *    write(t_head(5)(13:16),'(f4.2)') r_head(6)
	if (r_head(7) .ne. R_NULL)
     *    write(t_head(5)(26:29),'(f4.2)') r_head(7)
	if (r_head(8) .ne. R_NULL)
     *    write(t_head(5)(39:42),'(f4.2)') r_head(8)

c     text header 6: station name

        station_name = adjustl(rw_parms.comment)
	i = 0
        do while (i .lt. len(station_name))
	  i = i + 1
          if (iachar(station_name(i:i)) .eq. 0) station_name(i:i) = ' '
	enddo
        write(t_head(6)(11:40),'(a30)') station_name

c     text header 7: epicentral distance

	if (r_head(17) .ne. R_NULL) 
     *	  write(t_head(7)(18:26),'(f9.1)') r_head(17)

c     text header 8: instrument type and data source (default = 'USGS')

	header_version = kff_file_descr.header_version
	instr_code = kff_file_descr.instrument_code
	dsp_blk_ver = misc_ro_parms.dsp_blk_version
        instr_type = kmi_inst_type(header_version, instr_code,
     *           dsp_blk_ver)
	write(t_head(8)(11:15),'(a5)') instr_type
	t_head(8)(36:39) = 'USGS'

c     text header 9-11 are '*' by default

c -- determine altitude convention
c
c      Altus convention is range +90/-90, +90 = zenith, 0 = horiz, -90 = nadir
c
c      Convention used by USGS Earthquake Effects Project of Eq Hazards Team:
c      range 0-180, 0 = zenith, 90 = horizontal, 180 = nadir
c
c      method assumes number horizontal > number vertical components

      ialt_flag = 0
      i = 0
      do while (i .lt. rw_parms.nchannels)
        i = i + 1
        if (chan_rw_parms(i).altitude .eq. 90) ialt_flag = ialt_flag + 1
      enddo

      if (float(ialt_flag)/float(rw_parms.nchannels) .lt. 0.5) then
        ialt_flag = 0        ! Altus convention
        print *, 'Sensor altitude convention is -90 to 90 (Altus)'
      else
        ialt_flag = 1       ! 0-180 convention
        print *, 'Sensor altitude convention is 0-180'
      endif

c -- write out smc files with channel-specific parameters

c    first, build the template for the file names using the unique instrument id

c    file name is of the form iiiic.smc, where iiii is a 4-digit integer
c    (including leading zeros) of the instrument id, c is the channel
c    number transposed to an alphabetic character (1=a, 2=b ...),
c    and .smc is a standard file suffix

        if (kff_tag.id .lt. 0 .or. kff_tag.id .gt. 9999) then
          write(6,'(" Warning - DAS S/N out of range =",i10)')
     *        kff_tag.id
          kff_tag.id = 0
          write(6,'(" Reset to ",i4.4)') kff_tag.id
        endif

        call trim_c(fname, nc_fname)
        
        smcfile = ' '
        smcfile = fname(1:nc_fname)//'.x.smc'
        call trim_c(smcfile,nc_smcfile)
        
!	write(smcfile,'(i4.4,"_.smc")') kff_tag.id	! recorder ID

	inst_ch = 0	! physical channel in recorder
	mux_ch = 0	! multiplexed channel
	icount = 0	! counter for number of channels processed

        do while (icount .lt. rw_parms.nchannels)	! loop through channels

	  icount = icount + 1

c       find the next physical channel that was recorded

          if (rw_parms.channel_bitmap .ne. 0) then
            do while (.not. btest(rw_parms.channel_bitmap,inst_ch))
              inst_ch = inst_ch + 1
            enddo
          endif
	  inst_ch = inst_ch + 1

	  mux_ch = mux_ch + 1

c	open the output file

	  write(smcfile(nc_fname+2:nc_fname+2),'(a1)')
     :          achar(inst_ch+96)
          open(unit=8, file=smcfile(1:nc_smcfile), 
     :         status='unknown', iostat=ios)
          if(ios .ne. 0) then
            write(6,'(" Error in filename for inst_ch",i3,", mux_ch",
     *          i3,": ",a)') inst_ch, mux_ch, trim(smcfile)
            write(smcfile(nc_fname+2:nc_fname+2),'(a1)') achar(63)
            write(6,'("   write to file: ",a)') trim(smcfile)
            open(unit=8, file=smcfile(1:nc_smcfile), 
     :         status='unknown', iostat=ios)
          endif
	  rewind(unit=8)

c -- fill in integer headers

	  i_head(9) = inst_ch

	  i_head(12) = I_NULL					! sensor serial number
	  sensor_serial_num =
     *		chan_rw_parms(inst_ch).sensor_serial_number
	  jhi = chan_rw_parms(inst_ch).sensor_serial_number_ext
	  call mvbits(jhi,0,16,sensor_serial_num,16)
	  if (sensor_serial_num .ne. 0) i_head(12) = sensor_serial_num

	  select case (chan_rw_parms(inst_ch).sensor_type)	! sensor type

	    case(10)
	      i_head(15) = 31		! Kinemetrics FBA-11

	    case(11)
	      i_head(15) = 127		! Kinemetrics FBA-4g

	    case(12)
	      i_head(15) = 128		! Kinemetrics FBA-2g

	    case(13)
	      i_head(15) = 129		! Kinemetrics FBA-1g

	    case(14)
	      i_head(15) = 130		! Kinemetrics FBA-0.5g

	    case(15)
	      i_head(15) = 131		! Kinemetrics FBA-0.25g

	    case(16)
	      i_head(15) = 132		! Kinemetrics FBA-0.1g

	    case(20)
	      i_head(15) = 125		! Kinemetrics FBA-23

	    case(30)
	      i_head(15) = 133		! WR1

	    case(32)
	      i_head(15) = 126		! Episensor

	    case(33)
	      i_head(15) = 1054		! S6000

	    case(34)
	      i_head(15) = 1301		! Mark Products L22

	    case(35)
	      i_head(15) = 1300		! Mark Products L4C

	    case(36)
	      i_head(15) = 1203		! CMG3

	    case(37)
	      i_head(15) = 1202		! CMG3T

	    case(38)
	      i_head(15) = 1205		! CMG40T

	    case(39)
	      i_head(15) = 200		! CMG5

	    case(40)
	      i_head(15) = 501		! KS-2000

	    case default
	      i_head(15) = I_NULL

	  end select

c    fill in real headers

	  r_head(19) = R_NULL					! digitization units, counts/volt
	  if (chan_rw_parms(inst_ch).fullscale .ne. 0.)
     *	    r_head(19) = 2**(misc_ro_parms.sample_bytes*8 - 1)
     *		/chan_rw_parms(inst_ch).fullscale

	  r_head(22) = R_NULL					! natural frequency, Hz
	  if (chan_rw_parms(inst_ch).natural_frequency .ne. 0.)
     *	    r_head(22) = chan_rw_parms(inst_ch).natural_frequency

	  r_head(23) = R_NULL
	  if (chan_rw_parms(inst_ch).damping .ne. 0.)		! damping, fraction of critical
     *	    r_head(23) = chan_rw_parms(inst_ch).damping

	  r_head(24) = R_NULL					! sensitivity, volts/cm/s/s
	  if (chan_rw_parms(inst_ch).sensitivity .ne. 0.)
     *	    r_head(24) = chan_rw_parms(inst_ch).sensitivity/g

	  r_head(25) = R_NULL					! amplifier gain
c	  if (chan_rw_parms(inst_ch).gain .ne. 0)
c     *	    r_head(25) = float(chan_rw_parms(inst_ch).gain)

	  r_head(25) =
     *      20.*alog10(2.**23/chan_rw_parms(inst_ch).fullscale)

	  i1 = (mux_ch-1)*stream_ro_parms.nscans + 1
	  i = i1

	  r_head(29) = 0.					! time of maximum amplitude (s)
          r_head(30) = seis(i1)    				! maximum amplitude
	  r_head(31) = 0.					! time of minimum amplitude (s)
          r_head(32) = seis(i1)    				! minimum amplitude

	  do while (i .lt. mux_ch*stream_ro_parms.nscans)
	    i = i + 1
            if (seis(i) .gt. r_head(30)) then
	      r_head(29) = float(i-i1)
              r_head(30) = seis(i)
            else if (seis(i) .lt. r_head(32)) then
	      r_head(31) = float(i-i1)
              r_head(32) = seis(i)
	    endif
	  enddo
	  r_head(29) = r_head(29)/float(stream_rw_parms.sps)
	  r_head(31) = r_head(31)/float(stream_rw_parms.sps)

c    fill in text headers and misc integer headers

	  write(t_head(3)(5:5),'(a1)') achar(inst_ch+96)	! channel id (a,b,c,...)

	  t_head(6)(53:57) = '     '				! component and azimuth
	  i_head(13) = I_NULL
	  i_head(14) = I_NULL

	  iaz = chan_rw_parms(inst_ch).azimuth
	  if (iaz .eq. 359) iaz = 360		! adjustment for early versions of firmware
						!   where the value 360 was not allowed

          ialt = chan_rw_parms(inst_ch).altitude     ! Altus convention
          if (ialt_flag .eq. 1) then                 ! if convention is 0-180, convert to Altus
            ialt = 90 - ialt
          endif
          if (ialt .eq. 90) then                ! vertical UP
            t_head(6)(53:57) = ' UP  '
            i_head(13) = 90 - ialt
          else if (ialt .eq. -90) then          ! vertical DOWN
            t_head(6)(53:57) = ' DOWN'
            i_head(13) = 90 - ialt
          else if (iabs(ialt) .ne. 0) then      ! tilted
            t_head(6)(53:57) = ' TILT'
            i_head(13) = 90 - ialt
            i_head(14) = iaz
          else                                  ! otherwise assume horizontal
            if (iaz .eq. 0) then    ! correct 0 to 360 to avoid ambiguity
              iaz = iaz + 360
              print *, 'Horizontal azimuth changed from 0 to 360'
            endif
            write(t_head(6)(53:57),'(i3)') iaz
            i_head(14) = iaz
            if (ialt .eq. 0 .and. iaz .eq. 0)
     *        write(6,'( "Warning: ambiguous component orientation ",
     *        "for channel",i3,"; altitude and azimuth are 0")') inst_ch

c            ch_id = chan_rw_parms(inst_ch).id(1:1) ! use channel id to resolve ambiguity
c            if (lge(ch_id,'a') .and. lle(ch_id,'z')) 
c     *                  ch_id = achar(iachar(ch_id) - 32)  ! convert lower to upper case
c            if (ch_id .eq. 'U' .or. ch_id .eq. 'V' 
c     *                  .or. ch_id .eq. 'Z') then       ! vertical
	  endif

	  peak = r_head(30)					! peak value
	  if (abs(r_head(32)) .gt. peak) peak = r_head(32)
	  write(t_head(7)(42:50),'(f9.2)') peak

c    write the smc file

	  write(8,'(a)') t_head
	  write(8,'(8(i10))') i_head
	  write(8,'(5(1pe15.7e2))') r_head
	  write(8,'(1h|)')
	  write(8,'("| Converted using program evt2smc ",
     *		i4,2(1h/,i2.2),1x,i2,2(1h:,i2.2))') 
     *		proc_val(1), proc_val(2), proc_val(3),
     *		proc_val(5), proc_val(6), proc_val(7)
          write(8,'("| Input file: ",a)') trim(fname)
	  if (n_corrupt_segments .gt. 0) then
	    rewind(lune)
	    icom = 0
	    do while (icom .lt. n_corrupt_segments)
	      icom = icom + 1
	      read(lune,'(a)') comment
	      write(8,'(a)') trim(comment)
	    enddo
	  endif
          write(8,'(8(1pe10.4e1))') (seis(i),
     *      i=(mux_ch-1)*stream_ro_parms.nscans+1,
     *      mux_ch*stream_ro_parms.nscans)

	  close(unit=8)

	enddo


90	continue

	close(unit=lune)

        return

	end
	
	include '\forprogs\evt2smc_subs.for'
 	
 	include '\forprogs\skipcmnt.for'
 	include '\forprogs\trim_c.for'
 	include '\forprogs\upstr.for'
 	include '\forprogs\get_lun.for'
	
