* ------------------ BEGIN USC2ASC -----------------------------
      Program USC2ASC

* Read a control file with info for 1 to 10 usc files.  Read
* the usc file and reformat to produce a column file (actually, in
* CoPlot parlance, a wrapped ascii file).

* This version works only with V1 USC files (unevenly sampled)
* These files have all components in each file

* The basic use is to produce one file with three components that can be used
* by CoPlot to make a plot.

* Here as a sample input file:

*Control file for USC2ASC      ! first line
*Name of output file:
* usc2asc.asc
*Want blank or 1e37 for blanks (1=blank)
* 1
*1.Input fname,2.colm tag,3.ndecim,tskip,tlength,isign_ts,tshift (+ to right)
* \forprogs\test\v1x0300.usc
*   v1x0300                      ! up to 7 characters, starting in any column
*   1  0.0 999.0 +1 0.0 ! ndecim, tskip, tlength, isign_ts, tshift (+ to right)
* \forprogs\test\v1x0600.usc
*   v1x0600                      ! up to 7 characters, starting in any column
*   1  0.0 999.0 +1 0.0 ! ndecim, tskip, tlength, isign_ts, tshift (+ to right)
*stop

* Dates: 05/22/01 - Written by D. Boore, patterned after smc2asc.for
*          07/17/03 - Add sps parameter to smc_npts

      parameter(nts_max = 10)
      real ts(:,:), sps(nts_max), tshift(nts_max), 
     :     tskip(nts_max), tlength(nts_max)
      real spsb4(nts_max), tlengthb4(nts_max)
      allocatable :: ts

      integer npts(nts_max), nptsb4(nts_max), 
     :        ndecim(nts_max), isign_ts(nts_max)
      real real_head(50)
      integer int_head(48)
      character char_head(11)*80, comments(500)*80
      character f_ctl*40, f_out*40, f_ts(nts_max)*40, buf*40,
     :  colhead(nts_max)*11, ts_c(nts_max)*11, idtag*40
      logical f_ctl_exist, f_ts_exist

*      npts_max = 100000            ! depends on dimensions statement
      

* Get name of input file:
      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl(1:4) .eq. '    ') stop
        inquire(file=f_ctl, exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

* Open file 
      call get_lun(nu_ctl)      
      open(unit=nu_ctl, file=f_ctl, status='unknown')

* Read number of time series to process:
*   Skip header lines:
      call skip(nu_ctl,1)

* Read output file name:
*   Skip text lines:
      call skip(nu_ctl,1)
      f_out = ' '
      read(nu_ctl, '(a)') f_out

* Read variable to control blank or 1e37 (iblank = 1 ==> blank):
*   Skip text lines:
      call skip(nu_ctl,1)
      read(nu_ctl, *) iblank

* Loop over time series:
*  Skip text lines:
      call skip(nu_ctl,1)

      nts = 0

1000  continue

* Read file name:
        buf = ' '
        read(nu_ctl, '(a)') buf
        call upstr(buf)
        call trim_c(buf,nc_buf)

* Check for "STOP":
        if (buf(1:4) .eq. 'STOP') go to 2000

* Check for nts > max number
        if (nts + 1 .gt. nts_max) then
           write(*,*)
           write(*, '(a   )') 
     :    ' nts+1 > nts_max; ignoring remaining ts'
           write(*,*)
           go to 2000
        end if

* Passed tests; proceed
        nts = nts + 1
        f_ts(nts) = ' '
        f_ts(nts) = buf(1:nc_buf)
          
        inquire(file=f_ts(nts), exist=f_ts_exist)
        if (.not. f_ts_exist) then
          write(*,'(3a)') ' ****** FILE ', f_ts(nts), 
     :          ' DOES NOT EXIST; QUITTING!!! ******* '
          close(nu_out)
          close(nu_ctl)
          stop
        end if
* Read idtag:
        buf = ' '
        read(nu_ctl, '(a)') buf
        call RCC(1,buf,40,idtag,nc_id,ibgn,iend)
        if (nc_id .gt. 8) nc_id = 8
        write(*,*)
        write(*,'(2a)') '  idtag = ', idtag(1:nc_id)
        
* Read ndecim, etc:
        read(nu_ctl,*) 
     :   ndecim(nts), tskip(nts), tlength(nts), 
     :   isign_ts(nts), tshift(nts)

        write(*,'(2a)') '  f_ts = ', f_ts(nts)
        write(*,'(a)') 
     :      ' nts, ndecim(nts), tskip, tlength, isign_ts, tshift = '
        write(*,*)
     :        nts, ndecim(nts), tskip(nts), tlength(nts), 
     :        isign_ts(nts), tshift(nts)
 
* Loop over channels:
  
      nchn = 0

2000  continue

* Read text headers:

      nhead_usc = 13
      do i = 1, nhead_usc
        thead_usc(i) = ' '
        read(nu_in,'(a)', end=666) thead_usc(i)
      end do

      nchn = nchn + 1
      write(*,'(a,1x,i2)') '   Working on channel ', nchn

* Check for more than 3 channels:
      if (nchn .gt. 3) then
         write(*,'(a,1x,i5,a)') 
     :       ' !!! nchn = ', nchn, ', > 3; QUITTING !!!'
      end if

* Read integer headers:
      read(nu_in,'(16i5)') (ihead_usc(i), i=1,100)

* Read real headers:

      read(nu_in, '(8f10.3)') (rhead_usc(i), i=1,50)

* First get n_ts for array allocation:

* Get n_ts_max (= n_ts for first trace acc, increased by 1.1)

      n_in = ihead_usc(28)
      n_ts_max = 1.1*float(n_in)

* Allocate array:
      allocate (y_in(n_ts_max), t_in(n_ts_max))

* Read time series:
      read(nu_in, '(10f8.4)') (t_in(i), y_in(i), i = 1, n_in)
* Correct acceleration to cm/s/s:   ! NO-- Units are in cm/s/s
      do j = 1, n_in
        y_in(j) = 981.0 * rhead_usc(5) * y_in(j)
      end do

* Set up the column headings:
        colhead(nts) = ' '
        colhead(nts) = 'ts:'//idtag(1:nc_id)//'........'
        write(*,'(2a)') ' colhead = ', colhead(nts)

* Get number of points on this loop:

        call smc_npts(f_ts(nts),npts(nts),sps_tmp)

        write(*,'(a,2(1x,i6))') ' nts, npts(nts) = ', nts, npts(nts)

        go to 1000  ! loop back for another file

2000  continue

      close(unit=nu_ctl)

* Figure out largest value of npts and allocate the array:
      call imnmax(npts,1,nts,1,imin,imax) 
      write(*,*)
      write(*, '(a, 2(1x,i5))') ' imin, imax = ', imin, imax
      write(*, '(a, 2(1x,i5))') ' nts,nts_max = ', nts, nts_max

      allocate( ts(imax,nts_max))

* Now read the data from the files:
     
      do i = 1, nts
        call SMCRead(f_ts(i), tskip(i), tlength(i),
     :               ts(1,i),  
     :               char_head, int_head, real_head, comments)
        npts(i) = int_head(17)
        sps(i) = real_head(2)

* Decimate:
        nptsb4(i) = npts(i)
        spsb4(i) = sps(i)
        tlengthb4(i) = tlength(i)
        nt = 0
        do j = 1, npts(i), ndecim(i)
          nt = nt + 1
          ts(nt,i) = float(isign_ts(i)) * ts(j,i)
        end do
        npts(i) = nt
        sps(i) = sps(i)/float(ndecim(i))
        tlength(i) = float(npts(i)-1)/sps(i)
      end do

* Write output:

* Open output file:
      call get_lun(nu_out)      
      open(unit=nu_out, file=f_out, status='unknown')

      write(nu_out, '(a,1x,i2)') 
     :     ' Number of variables = ', 2*nts
      write(nu_out, '(a,1x,i3)') 
     :     ' Variable names start on line # ', 4+4*nts+1
      write(nu_out, '(a,1x,i3)') 
     :     ' Data starts on line # ', 4+4*nts+2

      write(nu_out, '(2a)') ' File with input parameters: ', f_ctl
 
      do i = 1, nts
        write(nu_out, '(2a)') 
     :    ' File with time series: ',f_ts(i)
        write(nu_out, '(3x,a,i5,1x,f7.3,1x,f8.1,1x,i3,1x,f7.3)') 
     :    ' ndecim, tskip, tlength, isign_ts, tshift = ',
     :      ndecim(i), tskip(i), tlength(i), isign_ts(i), tshift(i)        
        write(nu_out, '(3x, a, i5, 1x, f7.3, 1x,1pe10.3)') 
     :    ' Before decimation: npts, sps, tlength = ', 
     :      nptsb4(i), spsb4(i), tlengthb4(i)
        write(nu_out, '(3x, a, i5, 1x, f7.3, 1x,1pe10.3)') 
     :    ' After decimation: npts, sps, tlength = ', 
     :      npts(i), sps(i), tlength(i)
      end do

      write(nu_out, '(10(1x,3x,a4,1x,a11))') 
     :    ('time', colhead(j), j = 1, nts)
      
*      if (imax .gt. npts_max) then
*        write(*, '(a,1x,i6,1x,a)') ' **** WARNING ****, imax = ',
*     :    imax, ', which is greater than npts_max; QUITTING!'
*        stop
*      end if

* Find new imax:
      call imnmax(npts,1,nts,1,imin,imax) 

      do i = 1, imax

* Account for unequal number of points:
        do j = 1, nts
          if (i .le. npts(j)) then              ! fill output string with value
            write(ts_c(j), '(1pe11.4)') ts(i,j)
* Note: best if could use blanks, but CoPlot does not import this
* correctly as wrapped ascii.  It would import properly if I made
* a column file, but I am reluctant to strip off the informative header lines 

          else                                  ! fill with blanks
            if (iblank .eq. 1) then
              ts_c(j) = ' '
            else                                  ! fill with very large number
              write(ts_c(j), '(1pe11.4)') 1.0e37
            end if
          end if
        end do
        write(nu_out, '(10(1x,f7.3,1x,a))')
     :    (float(i-1)/sps(j)+tshift(j),ts_c(j), j = 1, nts)
      end do

      deallocate(ts)

      close(unit=nu_out)

      stop
      end
* ------------------ END USC2ASC -----------------------------

      include '\forprogs\SMCRead.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\imnmax.for'
      include '\forprogs\skip.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\upstr.for'
      include '\forprogs\smc_npts.for'
      include '\forprogs\rc_subs.for'

      deallocate(t_in, y_in)

*  check for end-of-channel marker:
      buf = ' '
      read(nu_in, '(a)') buf
      endchn = ' '
      call RCC (1,buf,80,endchn,NC,ibgn,iend)

      if (endchn(1:2) .ne. '/&') then
         write(*,'(a)') ' Problem with endchn, ne /&, quitting'
         stop
      end if

*  go back for a new channel:

      go to 2000

